import { SimklAnimeIdRequest, SimklAnimeShort, SimklAnimeExtended, SimklAnimeEpisodesRequest, SimklAnimeEpisode, SimklAnimeTrendingRequest, SimklAnimeTrendingShort, SimklAnimeTrendingExtended, SimklAnimeGenreRequest, SimklAnimeGenre, SimklAnimePremieresRequest, SimklAnimePremiere, SimklAnimeAiringRequest, SimklAnimeAiring, SimklAnimeBestRequest, SimklAnimeBest } from '../../models/simkl-anime.model.cjs';
import { SimklClientEndpoint } from '../../models/simkl-client.model.cjs';
import '../../models/simkl-common.model.cjs';
import '../../models/simkl-episode.model.cjs';
import '../../models/simkl-rating.model.cjs';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

declare const anime: {
    /**
     * Get detail info about the Anime
     *
     * Same as /tv/:id endpoint + added anime_type,en_title fields.
     *
     * @see [anime-summary](https://simkl.docs.apiary.io/reference/anime/summary/get-detail-info-about-the-anime}
     */
    id: SimklClientEndpoint<SimklAnimeIdRequest, SimklAnimeShort & Partial<SimklAnimeExtended>, true>;
    /**
     * Get Anime episodes
     *
     * @auth client
     * @extended full
     *
     * @see [anime-episodes](https://simkl.docs.apiary.io/reference/anime/episodes/get-anime-episodes}
     */
    episodes: SimklClientEndpoint<SimklAnimeEpisodesRequest, SimklAnimeEpisode[], true>;
    /**
     * Get trending anime series
     *
     * @auth client
     * @extended discover
     *
     * @see [anime-trending](https://simkl.docs.apiary.io/reference/anime/trending/get-trending-anime-series}
     */
    trending: SimklClientEndpoint<SimklAnimeTrendingRequest, (SimklAnimeTrendingShort & Partial<SimklAnimeTrendingExtended>)[], true>;
    /**
     * Get items filtered by genre, years etc...
     *
     * This endpoint accepts all parameters from the https://simkl.com/anime/all/, select the necessary filters and copy parameters from the url.
     * Genres API duplicates the urls of the Genres on the website so create a filter on the website and add it to genres API.
     *
     * @auth client
     * @pagination true
     *
     * @see [anime-genres](https://simkl.docs.apiary.io/reference/anime/genres/get-items-filtered-by-genre,-years-etc...}
     */
    genres: SimklClientEndpoint<SimklAnimeGenreRequest, SimklAnimeGenre[], true>;
    /**
     * Get latest premieres
     *
     * @auth client
     * @pagination true
     *
     * @see [anime-premieres](https://simkl.docs.apiary.io/reference/anime/premieres/get-latest-premieres}
     */
    premieres: SimklClientEndpoint<SimklAnimePremieresRequest, SimklAnimePremiere[], true>;
    /**
     * Get Airing Anime
     *
     * @auth client
     *
     * @see [anime-airing](https://simkl.docs.apiary.io/reference/anime/airing/get-airing-anime}
     */
    airing: SimklClientEndpoint<SimklAnimeAiringRequest, SimklAnimeAiring[], true>;
    /**
     * Get best of all Anime
     *
     * @auth client
     *
     * @see [anime-best](https://simkl.docs.apiary.io/reference/anime/best/get-best-of-all-anime}
     */
    best: SimklClientEndpoint<SimklAnimeBestRequest, SimklAnimeBest[], true>;
};

export { anime };
