import { SimklSearchIdResponse, SimklSearchTextRequest, SimklSearchTextShow, SimklSearchTextAnime, SimklSearchTextMovie, SimklSearchFileEpisode } from '../../models/simkl-search.model.cjs';
import { SimklClientEndpoint } from '../../models/simkl-client.model.cjs';
import { SimklCommonQuery } from '../../models/simkl-common.model.cjs';
import { SimklMovieShort } from '../../models/simkl-movie.model.cjs';
import '../../models/simkl-anime.model.cjs';
import '../../models/simkl-episode.model.cjs';
import '../../models/simkl-rating.model.cjs';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';
import '../../models/simkl-show.model.cjs';

declare const search: {
    /**
     * You can lookup items by their ID using this endpoint.
     *
     * Supports IMDB, TVDB, TMDB, AniDB, Hulu, Netflix, MAL, Crunchyroll ID.
     *
     * @auth client
     *
     * @see [id-lookup]{@link https://simkl.docs.apiary.io/reference/search/id-lookup/get-items-by-id}
     */
    id: SimklClientEndpoint<SimklCommonQuery, SimklSearchIdResponse, true>;
    /**
     * Search items by title, sorted by relevance (what people search most).
     *
     * This method will respond with Standard Media Object + additional fields if extended parameter passed.
     * For movies or anime with movie type, tmdb id points to the movies section on TMDB site, otherwise to the TV section.
     *
     * Page limit is 20, max items per page is 50
     *
     * @auth client
     * @pagination true
     * @extended full
     *
     * @see [text-search]{@link https://simkl.docs.apiary.io/reference/search/text/get-items-based-on-text-query}
     */
    text: SimklClientEndpoint<SimklSearchTextRequest, SimklSearchTextShow[] | SimklSearchTextAnime[] | SimklSearchTextMovie[], true>;
    /**
     * Use it if you have a filename and want to get simkl_id based on it.
     * Right now TV Shows and Anime files can be recognized the best.
     * Movies are harder to recognize without using the hash.
     * You can search by filename or by full folder+filename (see request examples).
     *
     * @see [file-search]{@link https://simkl.docs.apiary.io/reference/search/file/find-show,-anime-or-movie-by-file}
     */
    file: SimklClientEndpoint<SimklSearchTextRequest, SimklMovieShort | SimklSearchFileEpisode, true>;
};

export { search };
