import { SimklEpisodeShort, SimklEpisodeExtended } from '../../models/simkl-episode.model.js';
import { SimklShowIdRequest, SimklShowShort, SimklShowExtended, SimklShowEpisodesRequest, SimklShowTrendingRequest, SimklShowTrendingShort, SimklShowTrendingExtended, SimklShowGenreRequest, SimklShowGenre, SimklShowPremieresRequest, SimklShowPremiere, SimklShowAiringRequest, SimklShowAiring, SimklShowBestRequest, SimklShowBest } from '../../models/simkl-show.model.js';
import { SimklClientEndpoint } from '../../models/simkl-client.model.js';
import '../../models/simkl-common.model.js';
import '../../models/simkl-rating.model.js';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

declare const show: {
    /**
     * Get detail info about the TV Show
     *
     * @auth client
     * @extended full
     *
     * @see [show-summary](https://simkl.docs.apiary.io/reference/tv/summary/get-detail-info-about-the-tv-show}
     */
    id: SimklClientEndpoint<SimklShowIdRequest, SimklShowShort & Partial<SimklShowExtended>, true>;
    /**
     * Get TV Show episodes
     *
     * @auth client
     * @extended full
     *
     * @see [show-episodes](https://simkl.docs.apiary.io/reference/tv/episodes/get-tv-show-episodes}
     */
    episodes: SimklClientEndpoint<SimklShowEpisodesRequest, (SimklEpisodeShort & Partial<SimklEpisodeExtended>)[], true>;
    /**
     * Get trending TV series
     *
     * @auth client
     * @extended discover
     *
     * @see [show-trending](https://simkl.docs.apiary.io/reference/tv/trending/get-trending-tv-series}
     */
    trending: SimklClientEndpoint<SimklShowTrendingRequest, (SimklShowTrendingShort & Partial<SimklShowTrendingExtended>)[], true>;
    /**
     * Get items filtered by genre, years etc...
     *
     * This endpoint accepts all parameters from the https://simkl.com/tv/all/, select the necessary filters and copy parameters from the url.
     * Genres API duplicates the urls of the Genres on the website so create a filter on the website and add it to genres API.
     *
     * @auth client
     * @pagination true
     *
     * @see [show-genres](https://simkl.docs.apiary.io/reference/tv/genres/get-items-filtered-by-genre,-years-etc...}
     */
    genres: SimklClientEndpoint<SimklShowGenreRequest, SimklShowGenre[], true>;
    /**
     * Get latest premieres
     *
     * @auth client
     * @pagination true
     *
     * @see [show-premieres](https://simkl.docs.apiary.io/reference/tv/premieres/get-latest-premieres}
     */
    premieres: SimklClientEndpoint<SimklShowPremieresRequest, SimklShowPremiere[], true>;
    /**
     * Get Airing TV Shows
     *
     * @auth client
     *
     * @see [show-airing](https://simkl.docs.apiary.io/reference/tv/airing/get-airing-tv-shows}
     */
    airing: SimklClientEndpoint<SimklShowAiringRequest, SimklShowAiring[], true>;
    /**
     * Get best of all TV Shows
     *
     * @auth client
     *
     * @see [show-best](https://simkl.docs.apiary.io/reference/tv/best/get-best-of-all-tv-shows}
     */
    best: SimklClientEndpoint<SimklShowBestRequest, SimklShowBest[], true>;
};

export { show };
