import { SimklActivity } from '../models/simkl-activity.model.js';
import { SimklAnimeIdRequest, SimklAnimeShort, SimklAnimeExtended, SimklAnimeEpisodesRequest, SimklAnimeEpisode, SimklAnimeTrendingRequest, SimklAnimeTrendingShort, SimklAnimeTrendingExtended, SimklAnimeGenreRequest, SimklAnimeGenre, SimklAnimePremieresRequest, SimklAnimePremiere, SimklAnimeAiringRequest, SimklAnimeAiring, SimklAnimeBestRequest, SimklAnimeBest } from '../models/simkl-anime.model.js';
import { SimklAuthenticationAuthorizeRequest, SimklAuthenticationTokenRequest, SimklAuthenticationToken, SimklAuthenticationPinCodeRequest, SimklAuthenticationCode, SimklAuthenticationCodeStatusRequest, SimklAuthenticationCodeStatusResponse } from '../models/simkl-authentication.model.js';
import { SimklCalendarShow, SimklCalendarMonthRequest, SimklCalendarAnime, SimklCalendarMovie } from '../models/simkl-calendar.model.js';
import { SimklCheckinRequest } from '../models/simkl-checkin.model.js';
import { SimklClientEndpoint } from '../models/simkl-client.model.js';
import { SimklCommonQuery } from '../models/simkl-common.model.js';
import { SimklEpisodeShort, SimklEpisodeExtended } from '../models/simkl-episode.model.js';
import { SimklMovieShort, SimklMovieIdRequest, SimklMovieExtended, SimklMovieTrendingRequest, SimklMovieTrending } from '../models/simkl-movie.model.js';
import { SimklRatingRequest, SimklRating } from '../models/simkl-rating.model.js';
import { SimklRedirectRequest, SimklRedirectWatchedRequest } from '../models/simkl-redirect.model.js';
import { SimklSearchIdResponse, SimklSearchTextRequest, SimklSearchTextShow, SimklSearchTextAnime, SimklSearchTextMovie, SimklSearchFileEpisode } from '../models/simkl-search.model.js';
import { SimklShowIdRequest, SimklShowShort, SimklShowExtended, SimklShowEpisodesRequest, SimklShowTrendingRequest, SimklShowTrendingShort, SimklShowTrendingExtended, SimklShowGenreRequest, SimklShowGenre, SimklShowPremieresRequest, SimklShowPremiere, SimklShowAiringRequest, SimklShowAiring, SimklShowBestRequest, SimklShowBest } from '../models/simkl-show.model.js';
import { SimklSyncHistoryRequest, SimklSyncHistoryResponse, SimklSyncAddHistoryRequest, SimklSyncAddHistoryResponse, SimklSyncCheckRequest, SimklSyncCheckResponse, SimklSyncRemoveHistoryRequest, SimklSyncRemoveHistoryResponse, SimklSyncRatingRequest, SimklSyncAddRatingRequest, SimklSyncAddRatingResponse, SimklSyncRemoveRatingRequest, SimklSyncRemoveRatingResponse, SimklSyncAddToListRequest, SimklSyncAddToListResponse, SimklSyncAddToCollectionRequest, SimklSynAddedCollectionResponse, SimklSyncRemoveFromCollectionRequest, SimklSyncRemoveCollectionResponse } from '../models/simkl-sync.model.js';
import { SimklUserLastArtRequest, SimklUserLastArt, SimklUserLastArtRedirectRequest, SimklUserSettings, SimklUserStatsRequest, SimklUserStats } from '../models/simkl-user.model.js';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

declare const simklApi: {
    authentication: {
        authorize: SimklClientEndpoint<SimklAuthenticationAuthorizeRequest, unknown, false>;
        token: SimklClientEndpoint<SimklAuthenticationTokenRequest, SimklAuthenticationToken, false>;
        pin: {
            code: SimklClientEndpoint<SimklAuthenticationPinCodeRequest, SimklAuthenticationCode, false>;
            status: SimklClientEndpoint<SimklAuthenticationCodeStatusRequest, SimklAuthenticationCodeStatusResponse, false>;
        };
    };
    calendar: {
        shows: {
            next: SimklClientEndpoint<Record<string, never>, SimklCalendarShow[], true>;
            month: SimklClientEndpoint<SimklCalendarMonthRequest, SimklCalendarShow[], true>;
        };
        anime: {
            next: SimklClientEndpoint<Record<string, never>, SimklCalendarAnime[], true>;
            month: SimklClientEndpoint<SimklCalendarMonthRequest, SimklCalendarAnime[], true>;
        };
        movies: {
            next: SimklClientEndpoint<Record<string, never>, SimklCalendarMovie[], true>;
            month: SimklClientEndpoint<SimklCalendarMonthRequest, SimklCalendarMovie[], true>;
        };
    };
    checkin: SimklClientEndpoint<SimklCheckinRequest, SimklCheckinRequest, false>;
    ratings: SimklClientEndpoint<SimklRatingRequest, SimklRating, true>;
    redirect: {
        to: SimklClientEndpoint<SimklRedirectRequest, unknown, false>;
        watched: SimklClientEndpoint<SimklRedirectWatchedRequest, unknown, false>;
    };
    search: {
        id: SimklClientEndpoint<SimklCommonQuery, SimklSearchIdResponse, true>;
        text: SimklClientEndpoint<SimklSearchTextRequest, SimklSearchTextShow[] | SimklSearchTextAnime[] | SimklSearchTextMovie[], true>;
        file: SimklClientEndpoint<SimklSearchTextRequest, SimklMovieShort | SimklSearchFileEpisode, true>;
    };
    show: {
        id: SimklClientEndpoint<SimklShowIdRequest, SimklShowShort & Partial<SimklShowExtended>, true>;
        episodes: SimklClientEndpoint<SimklShowEpisodesRequest, (SimklEpisodeShort & Partial<SimklEpisodeExtended>)[], true>;
        trending: SimklClientEndpoint<SimklShowTrendingRequest, (SimklShowTrendingShort & Partial<SimklShowTrendingExtended>)[], true>;
        genres: SimklClientEndpoint<SimklShowGenreRequest, SimklShowGenre[], true>;
        premieres: SimklClientEndpoint<SimklShowPremieresRequest, SimklShowPremiere[], true>;
        airing: SimklClientEndpoint<SimklShowAiringRequest, SimklShowAiring[], true>;
        best: SimklClientEndpoint<SimklShowBestRequest, SimklShowBest[], true>;
    };
    anime: {
        id: SimklClientEndpoint<SimklAnimeIdRequest, SimklAnimeShort & Partial<SimklAnimeExtended>, true>;
        episodes: SimklClientEndpoint<SimklAnimeEpisodesRequest, SimklAnimeEpisode[], true>;
        trending: SimklClientEndpoint<SimklAnimeTrendingRequest, (SimklAnimeTrendingShort & Partial<SimklAnimeTrendingExtended>)[], true>;
        genres: SimklClientEndpoint<SimklAnimeGenreRequest, SimklAnimeGenre[], true>;
        premieres: SimklClientEndpoint<SimklAnimePremieresRequest, SimklAnimePremiere[], true>;
        airing: SimklClientEndpoint<SimklAnimeAiringRequest, SimklAnimeAiring[], true>;
        best: SimklClientEndpoint<SimklAnimeBestRequest, SimklAnimeBest[], true>;
    };
    movie: {
        id: SimklClientEndpoint<SimklMovieIdRequest, SimklMovieShort | SimklMovieExtended, true>;
        trending: SimklClientEndpoint<SimklMovieTrendingRequest, SimklMovieTrending[], true>;
    };
    sync: {
        activity: SimklClientEndpoint<Record<string, never>, SimklActivity, true>;
        history: {
            get: SimklClientEndpoint<SimklSyncHistoryRequest, SimklSyncHistoryResponse, true>;
            add: SimklClientEndpoint<SimklSyncAddHistoryRequest, SimklSyncAddHistoryResponse, false>;
            check: SimklClientEndpoint<SimklSyncCheckRequest, SimklSyncCheckResponse, false>;
            remove: SimklClientEndpoint<SimklSyncRemoveHistoryRequest, SimklSyncRemoveHistoryResponse, false>;
        };
        ratings: {
            get: SimklClientEndpoint<SimklSyncRatingRequest, SimklSyncHistoryResponse, true>;
            add: SimklClientEndpoint<SimklSyncAddRatingRequest, SimklSyncAddRatingResponse, false>;
            remove: SimklClientEndpoint<SimklSyncRemoveRatingRequest, SimklSyncRemoveRatingResponse, false>;
        };
        list: {
            add: SimklClientEndpoint<SimklSyncAddToListRequest, SimklSyncAddToListResponse, false>;
        };
        collection: {
            add: SimklClientEndpoint<SimklSyncAddToCollectionRequest, SimklSynAddedCollectionResponse, false>;
            remove: SimklClientEndpoint<SimklSyncRemoveFromCollectionRequest, SimklSyncRemoveCollectionResponse, false>;
        };
    };
    user: {
        arts: {
            last: SimklClientEndpoint<SimklUserLastArtRequest, SimklUserLastArt, true>;
            redirect: SimklClientEndpoint<SimklUserLastArtRedirectRequest, unknown, true>;
        };
        settings: SimklClientEndpoint<Record<string, never>, SimklUserSettings, true>;
        stats: SimklClientEndpoint<SimklUserStatsRequest, SimklUserStats, true>;
    };
};
type SimklApi = typeof simklApi;

export { type SimklApi, simklApi };
