// lib/models/simkl-error.model.ts
import { ApiError, InvalidCsrfError, InvalidParameterError, PollingCancelledError, PollingExpiredError } from "@dvcol/base-http-client/utils/error";
var SimklErrorTypes = {
  SimklApiError: "SimklApiError",
  SimklRateLimitError: "SimklRateLimitError",
  SimklInvalidCsrfError: "SimklInvalidCsrfError",
  SimklUnauthorizedError: "SimklUnauthorizedError",
  SimklPollingExpiredError: "SimklPollingExpiredError",
  SimklPollingCancelledError: "SimklPollingCancelledError",
  SimklInvalidParameterError: "SimklInvalidParameterError"
};
var SimklApiError = class extends ApiError {
  constructor(message, error) {
    super(message, error);
    this.name = SimklErrorTypes.SimklApiError;
  }
};
var SimklInvalidParameterError = class extends InvalidParameterError {
  constructor(message) {
    super(message);
    this.name = SimklErrorTypes.SimklInvalidParameterError;
  }
};
var SimklPollingExpiredError = class extends PollingExpiredError {
  constructor(message) {
    super(message);
    this.name = SimklErrorTypes.SimklPollingExpiredError;
  }
};
var SimklPollingCancelledError = class extends PollingCancelledError {
  constructor(message) {
    super(message);
    this.name = SimklErrorTypes.SimklPollingCancelledError;
  }
};
var SimklUnauthorizedError = class extends SimklApiError {
  constructor(message, error) {
    super(message, error);
    this.name = SimklErrorTypes.SimklUnauthorizedError;
  }
};
var SimklRateLimitError = class extends SimklApiError {
  constructor(message, error) {
    super(message, error);
    this.name = SimklErrorTypes.SimklRateLimitError;
  }
};
var SimklInvalidCsrfError = class extends InvalidCsrfError {
  constructor({ state, expected } = {}) {
    super({ state, expected });
    this.name = SimklErrorTypes.SimklInvalidCsrfError;
  }
};

export {
  SimklErrorTypes,
  SimklApiError,
  SimklInvalidParameterError,
  SimklPollingExpiredError,
  SimklPollingCancelledError,
  SimklUnauthorizedError,
  SimklRateLimitError,
  SimklInvalidCsrfError
};
