import {
  SimklApiTransform
} from "./chunk-UUWXYJQS.js";
import {
  SimklAnimeGenreSection
} from "./chunk-SB72OIDE.js";
import {
  SimklBestFilter,
  SimklPremiereParam
} from "./chunk-TPGF55YD.js";
import {
  SimklApiAuthType,
  SimklApiExtended,
  SimklClientEndpoint
} from "./chunk-3HNK4KUT.js";

// lib/api/endpoints/anime.endpoint.ts
import { HttpMethod } from "@dvcol/common-utils/http";
var anime = {
  /**
   * Get detail info about the Anime
   *
   * Same as /tv/:id endpoint + added anime_type,en_title fields.
   *
   * @see [anime-summary](https://simkl.docs.apiary.io/reference/anime/summary/get-detail-info-about-the-anime}
   */
  id: new SimklClientEndpoint({
    method: HttpMethod.GET,
    url: "/anime/:id",
    opts: {
      auth: SimklApiAuthType.Client,
      extends: SimklApiExtended.Full,
      parameters: {
        path: {
          id: true
        },
        query: {
          extended: false
        }
      }
    },
    transform: SimklApiTransform.Extends[SimklApiExtended.Full]
  }),
  /**
   * Get Anime episodes
   *
   * @auth client
   * @extended full
   *
   * @see [anime-episodes](https://simkl.docs.apiary.io/reference/anime/episodes/get-anime-episodes}
   */
  episodes: new SimklClientEndpoint({
    method: HttpMethod.GET,
    url: "/anime/episodes/:id",
    opts: {
      auth: SimklApiAuthType.Client,
      extends: SimklApiExtended.Full,
      parameters: {
        path: {
          id: true
        },
        query: {
          extended: false
        }
      }
    },
    transform: SimklApiTransform.Extends[SimklApiExtended.Full]
  }),
  /**
   * Get trending anime series
   *
   * @auth client
   * @extended discover
   *
   * @see [anime-trending](https://simkl.docs.apiary.io/reference/anime/trending/get-trending-anime-series}
   */
  trending: new SimklClientEndpoint({
    method: HttpMethod.GET,
    url: "/anime/trending/:interval",
    opts: {
      auth: SimklApiAuthType.Client,
      extends: SimklApiExtended.Discover,
      parameters: {
        path: {
          interval: false
        },
        query: {
          extended: false
        }
      }
    },
    transform: SimklApiTransform.Extends[SimklApiExtended.Discover]
  }),
  /**
   * Get items filtered by genre, years etc...
   *
   * This endpoint accepts all parameters from the https://simkl.com/anime/all/, select the necessary filters and copy parameters from the url.
   * Genres API duplicates the urls of the Genres on the website so create a filter on the website and add it to genres API.
   *
   * @auth client
   * @pagination true
   *
   * @see [anime-genres](https://simkl.docs.apiary.io/reference/anime/genres/get-items-filtered-by-genre,-years-etc...}
   */
  genres: new SimklClientEndpoint({
    method: HttpMethod.GET,
    url: "/anime/genres/:genre/:type/:network/:year/:sort",
    seed: {
      genre: SimklAnimeGenreSection.All
    },
    opts: {
      auth: SimklApiAuthType.Client,
      pagination: true,
      parameters: {
        path: {
          genre: false,
          type: false,
          network: false,
          year: false,
          sort: false
        },
        query: {
          page: false,
          limit: false
        }
      }
    }
  }),
  /**
   * Get latest premieres
   *
   * @auth client
   * @pagination true
   *
   * @see [anime-premieres](https://simkl.docs.apiary.io/reference/anime/premieres/get-latest-premieres}
   */
  premieres: new SimklClientEndpoint({
    method: HttpMethod.GET,
    url: "/anime/premieres/:param",
    seed: {
      param: SimklPremiereParam.New
    },
    opts: {
      auth: SimklApiAuthType.Client,
      pagination: true,
      parameters: {
        path: {
          param: true
        },
        query: {
          type: false,
          page: false,
          limit: false
        }
      }
    }
  }),
  /**
   * Get Airing Anime
   *
   * @auth client
   *
   * @see [anime-airing](https://simkl.docs.apiary.io/reference/anime/airing/get-airing-anime}
   */
  airing: new SimklClientEndpoint({
    method: HttpMethod.GET,
    url: "/anime/airing",
    opts: {
      auth: SimklApiAuthType.Client,
      parameters: {
        query: {
          date: false,
          sort: false
        }
      }
    }
  }),
  /**
   * Get best of all Anime
   *
   * @auth client
   *
   * @see [anime-best](https://simkl.docs.apiary.io/reference/anime/best/get-best-of-all-anime}
   */
  best: new SimklClientEndpoint({
    method: HttpMethod.GET,
    url: "/anime/best/:filter",
    seed: {
      filter: SimklBestFilter.All
    },
    opts: {
      auth: SimklApiAuthType.Client,
      parameters: {
        path: {
          filter: true
        },
        query: {
          type: false
        }
      }
    }
  })
};

export {
  anime
};
