import { SimklApiParamsExtended, SimklApiExtended, SimklApiParamsPagination } from './simkl-client.model.js';
import { SimklMediaType, SimklIds, SimklAlternativeTitle, SimklAirDate, SimklAnimeAndShowStatuses, SimklTrailer, SimklEntityTypes, SimklEntityType, SimklTrendingIntervals, SimklGenreYears, SimklGenreSorts, SimklPremiereParams, SimklPremiereDates, SimklAiringSorts, SimklBestFilters } from './simkl-common.model.js';
import { SimklEpisode, SimklEpisodeMinimal } from './simkl-episode.model.js';
import { SimklRatings } from './simkl-rating.model.js';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

declare const SimklAnimeType: {
    readonly TV: "tv";
    readonly OVA: "ova";
    readonly ONA: "ona";
    readonly Movie: "movie";
    readonly Special: "special";
    readonly MusicVideo: "music video";
};
type SimklAnimeTypes = (typeof SimklAnimeType)[keyof typeof SimklAnimeType];
type SimklAnimeShort = {
    title: string;
    year: number;
    type: typeof SimklMediaType.Anime;
    ids: SimklIds<'slug' | 'simkl'>;
};
type SimklAnimeStudio = {
    id: number;
    name: string;
};
type SimklAnimeRecommendation = {
    title: string;
    en_title?: string;
    year: number;
    poster: string;
    anime_type: SimklAnimeTypes;
    users_percent: number;
    users_count: number;
    ids: SimklIds<'slug' | 'simkl'>;
};
type SimklAnimeRelation = {
    title: string;
    en_title?: string;
    year: number;
    poster: string;
    anime_type: SimklAnimeTypes;
    relation_type: string;
    is_direct: boolean;
    ids: SimklIds<'slug' | 'simkl'>;
};
type SimklAnimeExtended = SimklAnimeShort & {
    year_start_end: string;
    en_title?: string;
    alt_titles?: SimklAlternativeTitle[];
    anime_type: SimklAnimeTypes;
    studios?: SimklAnimeStudio[];
    season_name_year?: string;
    rank: number;
    poster: string;
    fanart: string;
    first_aired: string;
    last_aired: string;
    airs: SimklAirDate;
    runtime: number;
    certification: string;
    overview: string;
    genres: string[];
    country: string;
    total_episodes: number;
    status: SimklAnimeAndShowStatuses;
    network: string;
    ratings?: SimklRatings<'simkl' | 'mal'>;
    trailer?: SimklTrailer[];
    user_recommendations?: SimklAnimeRecommendation[];
    relations?: SimklAnimeRelation[];
};
type SimklAnime<T extends SimklEntityTypes = typeof SimklEntityType.Unknown> = T extends typeof SimklEntityType.Short ? SimklAnimeShort : T extends typeof SimklEntityType.Extended ? SimklAnimeExtended : SimklAnimeShort & Partial<SimklAnimeExtended>;
type SimklAnimeIdRequest = {
    /** Simkl ID or IMDB ID. */
    id: number | string;
} & SimklApiParamsExtended<typeof SimklApiExtended.Full>;
type SimklAnimeEpisodesRequest = {
    /** Simkl ID */
    id: number | string;
} & SimklApiParamsExtended<typeof SimklApiExtended.Full>;
type SimklAnimeEpisode<T extends SimklEntityTypes = typeof SimklEntityType.Unknown> = Omit<SimklEpisode<T>, 'season'>;
type SimklAnimeTrendingRequest = {
    /** Filter within the time period. */
    interval?: SimklTrendingIntervals | string;
} & SimklApiParamsExtended<typeof SimklApiExtended.Discover>;
type SimklAnimeTrendingShort = {
    poster: string;
    fanart: string;
    ids: SimklIds<'simkl_id'>;
    release_date: string;
    rank: number;
    drop_rate: string;
    watched: number;
    plan_to_watch: number;
    ratings: SimklRatings<'simkl' | 'mal'>;
    country: string;
    runtime: string;
    status: SimklAnimeAndShowStatuses;
    anime_type: SimklAnimeTypes;
    total_episodes: number;
    network: string;
};
type SimklAnimeTrendingExtended = SimklAnimeTrendingShort & {
    title: string;
    url: string;
    ids: SimklIds<'simkl_id' | 'slug' | 'tmdb'>;
    metadata: string;
    overview: string;
    genres: string[];
};
type SimklAnimeTrending<T extends SimklEntityTypes = typeof SimklEntityType.Unknown> = T extends typeof SimklEntityType.Short ? SimklAnimeTrendingShort : T extends typeof SimklEntityType.Extended ? SimklAnimeTrendingExtended : SimklAnimeTrendingShort & Partial<SimklAnimeTrendingExtended>;
declare const SimklAnimeGenreSection: {
    readonly Action: "action";
    readonly Adventure: "adventure";
    readonly Cars: "cars";
    readonly Comedy: "comedy";
    readonly Dementia: "dementia";
    readonly Demons: "demons";
    readonly Drama: "drama";
    readonly Ecchi: "ecchi";
    readonly Fantasy: "fantasy";
    readonly Game: "game";
    readonly Harem: "harem";
    readonly Historical: "historical";
    readonly Horror: "horror";
    readonly Josei: "josei";
    readonly Kids: "kids";
    readonly Magic: "magic";
    readonly MartialArts: "martial-arts";
    readonly Mecha: "mecha";
    readonly Military: "military";
    readonly Music: "music";
    readonly Mystery: "mystery";
    readonly Parody: "parody";
    readonly Police: "police";
    readonly Psychological: "psychological";
    readonly Romance: "romance";
    readonly Samurai: "samurai";
    readonly School: "school";
    readonly SciFi: "sci-fi";
    readonly Seinen: "seinen";
    readonly Shoujo: "shoujo";
    readonly ShoujoAi: "shoujo-ai";
    readonly Shounen: "shounen";
    readonly ShounenAi: "shounen-ai";
    readonly SliceOfLife: "slice-of-life";
    readonly Space: "space";
    readonly Sports: "sports";
    readonly SuperPower: "super-power";
    readonly Supernatural: "supernatural";
    readonly Thriller: "thriller";
    readonly Vampire: "vampire";
    readonly Yaoi: "yaoi";
    readonly Yuri: "yuri";
    readonly All: "all";
};
type SimklAnimeGenreSections = (typeof SimklAnimeGenreSection)[keyof typeof SimklAnimeGenreSection];
declare const SimklAnimeGenreType: {
    readonly All: "all-types";
    readonly Series: "series";
    readonly Movies: "movies";
    readonly OVAs: "ovas";
    readonly ONAs: "onas";
};
type SimklAnimeGenreTypes = (typeof SimklAnimeGenreType)[keyof typeof SimklAnimeGenreType];
declare const SimklAnimeGenreNetwork: {
    readonly All: "all";
    readonly TVTokyo: "tvtokyo";
    readonly TokyoMX: "tokyomx";
    readonly FujiTV: "fujitv";
    readonly TokyoBroadcastingSystem: "tokyobroadcastingsystem";
    readonly TVAsahi: "tvasahi";
    readonly WOWOW: "wowow";
    readonly NTV: "ntv";
    readonly ATX: "atx";
    readonly CTC: "ctc";
    readonly NHK: "nhk";
    readonly MBS: "mbs";
    readonly Animax: "animax";
    readonly CartoonNetwork: "cartoonnetwork";
    readonly ABC: "abc";
};
type SimklAnimeGenreNetworks = (typeof SimklAnimeGenreNetwork)[keyof typeof SimklAnimeGenreNetwork];
type SimklAnimeGenreRequest = {
    /** Default is all. */
    genre?: SimklAnimeGenreSections | string;
    /** Default is all-types. */
    type?: SimklAnimeGenreTypes | string;
    /** Default: all-networks (empty) */
    network?: SimklAnimeGenreNetworks | string;
    /** Default: 2010s */
    year?: SimklGenreYears | string;
    /** Default: rank */
    sort?: SimklGenreSorts | string;
} & SimklApiParamsPagination;
type SimklAnimeGenre = {
    title: string;
    year: number;
    date: string;
    url: string;
    poster: string;
    fanart: string;
    ids: SimklIds<'simkl_id' | 'slug'>;
    anime_type: SimklAnimeTypes;
    rank: number;
    ratings: SimklRatings<'simkl' | 'mal'>;
};
declare const SimklAnimePremiereType: {
    readonly All: "all";
    readonly Series: "series";
    readonly Movies: "movies";
    readonly OVAs: "ovas";
};
type SimklAnimePremiereTypes = (typeof SimklAnimePremiereType)[keyof typeof SimklAnimePremiereType];
type SimklAnimePremieresRequest = {
    param: SimklPremiereParams | string;
    type?: SimklAnimePremiereTypes | string;
} & SimklApiParamsPagination;
type SimklAnimePremiere = {
    title: string;
    year: number;
    date: string;
    poster: string;
    url: string;
    rank?: number;
    anime_type: SimklAnimeTypes;
    ids: SimklIds<'simkl_id' | 'slug'>;
    ratings?: SimklRatings<'simkl' | 'mal'>;
};
type SimklAnimeAiringRequest = {
    date?: SimklPremiereDates | string;
    sort?: SimklAiringSorts | string;
};
type SimklAnimeAiring = {
    title: string;
    year: number;
    date: string;
    poster: string;
    url: string;
    rank?: number;
    anime_type: SimklAnimeTypes;
    ids: SimklIds<'simkl_id' | 'slug'>;
    episode: Omit<SimklEpisodeMinimal, 'season'>;
};
declare const SimklAnimeBestType: {
    readonly All: "all";
    readonly TV: "tv";
    readonly Movies: "movies";
    readonly Music: "music";
    readonly OVAs: "ovas";
    readonly ONAs: "onas";
};
type SimklAnimeBestTypes = (typeof SimklAnimeBestType)[keyof typeof SimklAnimeBestType];
type SimklAnimeBestRequest = {
    filter: SimklBestFilters | string;
    type?: SimklAnimeBestTypes | string;
};
type SimklAnimeBest = {
    title: string;
    year: number;
    poster: string;
    url: string;
    ids: SimklIds<'simkl_id' | 'slug'>;
    ratings: SimklRatings<'simkl' | 'mal'>;
};

export { type SimklAnime, type SimklAnimeAiring, type SimklAnimeAiringRequest, type SimklAnimeBest, type SimklAnimeBestRequest, SimklAnimeBestType, type SimklAnimeBestTypes, type SimklAnimeEpisode, type SimklAnimeEpisodesRequest, type SimklAnimeExtended, type SimklAnimeGenre, SimklAnimeGenreNetwork, type SimklAnimeGenreNetworks, type SimklAnimeGenreRequest, SimklAnimeGenreSection, type SimklAnimeGenreSections, SimklAnimeGenreType, type SimklAnimeGenreTypes, type SimklAnimeIdRequest, type SimklAnimePremiere, SimklAnimePremiereType, type SimklAnimePremiereTypes, type SimklAnimePremieresRequest, type SimklAnimeRecommendation, type SimklAnimeRelation, type SimklAnimeShort, type SimklAnimeStudio, type SimklAnimeTrending, type SimklAnimeTrendingExtended, type SimklAnimeTrendingRequest, type SimklAnimeTrendingShort, SimklAnimeType, type SimklAnimeTypes };
