import { ApiError, InvalidParameterError, PollingExpiredError, PollingCancelledError, InvalidCsrfError } from '@dvcol/base-http-client/utils/error';
import { SimklApiResponse } from './simkl-client.model.cjs';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

declare const SimklErrorTypes: {
    readonly SimklApiError: "SimklApiError";
    readonly SimklRateLimitError: "SimklRateLimitError";
    readonly SimklInvalidCsrfError: "SimklInvalidCsrfError";
    readonly SimklUnauthorizedError: "SimklUnauthorizedError";
    readonly SimklPollingExpiredError: "SimklPollingExpiredError";
    readonly SimklPollingCancelledError: "SimklPollingCancelledError";
    readonly SimklInvalidParameterError: "SimklInvalidParameterError";
};
declare class SimklApiError<T = unknown> extends ApiError<SimklApiResponse<T>> {
    constructor(message: string, error?: Error | SimklApiResponse<T>);
}
declare class SimklInvalidParameterError extends InvalidParameterError {
    constructor(message?: string);
}
declare class SimklPollingExpiredError extends PollingExpiredError {
    constructor(message?: string);
}
declare class SimklPollingCancelledError extends PollingCancelledError {
    constructor(message?: string);
}
declare class SimklUnauthorizedError<T = unknown> extends SimklApiError<T> {
    constructor(message?: string, error?: Error | SimklApiResponse<T>);
}
declare class SimklRateLimitError<T = unknown> extends SimklApiError<T> {
    constructor(message?: string, error?: Error | SimklApiResponse<T>);
}
declare class SimklInvalidCsrfError extends InvalidCsrfError {
    constructor({ state, expected }?: {
        state?: string;
        expected?: string;
    });
}

export { SimklApiError, SimklErrorTypes, SimklInvalidCsrfError, SimklInvalidParameterError, SimklPollingCancelledError, SimklPollingExpiredError, SimklRateLimitError, SimklUnauthorizedError };
