import { SimklEntityTypes, SimklCommonQuery } from './simkl-common.model.cjs';

type SimklRatingScore = {
    rating: number;
    votes: number;
};
type SimklRatingsBase = {
    simkl: SimklRatingScore;
    imdb?: SimklRatingScore;
    mal?: SimklRatingScore & {
        rank: number;
    };
};
type SimklRatingsExtended = SimklRatingsBase & {
    imdb?: SimklRatingScore;
    mal?: SimklRatingScore & {
        rank: number;
    };
};
type SimklRatings<K extends keyof T, T = SimklRatingsExtended> = Partial<SimklRatingsExtended> & {
    [P in K]: T[P];
};
type SimklRating = {
    id: number;
    link: string;
    simkl: SimklRatingScore;
    imdb?: SimklRatingScore;
    rank: {
        type: SimklEntityTypes;
        value: number;
    };
    has_trailer: boolean;
};
declare const SimklRatingField: {
    readonly Rank: "rank";
    readonly DropRate: "droprate";
    readonly Simkl: "simkl";
    readonly External: "ext";
    readonly HasTrailer: "has_trailer";
    readonly All: readonly ["rank", "droprate", "simkl", "ext", "has_trailer"];
};
type SimklRatingFields = (typeof SimklRatingField)[keyof Omit<typeof SimklRatingField, 'All'>];
type SimklRatingRequest = SimklCommonQuery & {
    fields: string | SimklRatingFields | SimklRatingFields[];
};

export { type SimklRating, SimklRatingField, type SimklRatingFields, type SimklRatingRequest, type SimklRatingScore, type SimklRatings, type SimklRatingsBase, type SimklRatingsExtended };
