import { SimklAnimeShort } from './simkl-anime.model.js';
import { SimklApiParamsPagination, SimklApiParamsExtended, SimklApiExtended } from './simkl-client.model.js';
import { SimklCommonQuery, SimklAnimeAndShowStatuses, SimklIds, SimklMovieStatuses, SimklEntityType, SimklIdsExtended } from './simkl-common.model.js';
import { SimklMovieShort } from './simkl-movie.model.js';
import { SimklRatings } from './simkl-rating.model.js';
import { SimklShowShort } from './simkl-show.model.js';
import './simkl-episode.model.js';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

type SimklSearchIdRequest = SimklCommonQuery;
type SimklSearchEntity = {
    title: string;
    poster: string;
    year: number;
};
declare const SimklSearchEntityType: {
    readonly Tv: "tv";
    readonly Anime: "anime";
    readonly Movie: "movie";
};
type SimklSearchEntityTypes = (typeof SimklSearchEntityType)[keyof typeof SimklSearchEntityType];
type SimklSearchIdShow = SimklSearchEntity & {
    type: typeof SimklSearchEntityType.Tv;
    total_episodes: number;
    status: SimklAnimeAndShowStatuses;
    ids: SimklIds<'slug' | 'simkl'>;
};
type SimklSearchIdAnime = SimklSearchEntity & {
    type: typeof SimklSearchEntityType.Anime;
    total_episodes: number;
    status: SimklAnimeAndShowStatuses;
    ids: SimklIds<'slug' | 'simkl'>;
};
type SimklSearchIdMovie = SimklSearchEntity & {
    type: typeof SimklSearchEntityType.Movie;
    status: SimklMovieStatuses;
    ids: SimklIds<'slug' | 'simkl'>;
};
type SimklSearchIdResponse = (SimklSearchIdShow | SimklSearchIdAnime | SimklSearchIdMovie)[];
type SimklSearchTextRequest = {
    type: SimklSearchEntityTypes;
    q: string;
} & SimklApiParamsPagination & SimklApiParamsExtended<typeof SimklApiExtended.Full>;
type SimklSearchTextShow = SimklSearchEntity & {
    ids: SimklIds<'simkl_id' | 'slug' | 'tmdb'>;
    url?: string;
    ep_count?: number;
    rank?: number;
    status?: SimklAnimeAndShowStatuses;
    ratings?: SimklRatings<'simkl' | 'imdb'>;
};
type SimklSearchTextAnime = SimklSearchEntity & {
    title_en?: string;
    title_romaji?: string;
    type: SimklAnimeShort['type'];
    all_titles?: string[];
    url?: string;
    ep_count?: number;
    rank?: number;
    status?: SimklAnimeAndShowStatuses;
    ratings?: SimklRatings<'simkl' | 'mal'>;
    ids: SimklIds<'simkl_id' | 'slug' | 'tmdb'>;
};
type SimklSearchTextMovie = SimklSearchEntity & {
    ids: SimklIds<'simkl_id' | 'slug' | 'tmdb'>;
    all_titles?: string[];
    url?: string;
    rank?: number;
    ratings?: SimklRatings<'simkl' | 'imdb'>;
};
type SimklSearchTextResponse<T extends SimklSearchEntityTypes | typeof SimklEntityType.Unknown = typeof SimklEntityType.Unknown> = T extends typeof SimklSearchEntityType.Tv ? SimklSearchTextShow[] : T extends typeof SimklSearchEntityType.Anime ? SimklSearchTextAnime[] : T extends typeof SimklSearchEntityType.Movie ? SimklSearchTextMovie[] : T extends typeof SimklSearchEntityType.Tv ? SimklSearchTextShow[] : SimklSearchTextShow[] | SimklSearchTextAnime[] | SimklSearchTextMovie[];
type SimklSearchFileRequest = {
    /**
     * Trying to find this file in our DB.
     *
     * You can also use folders in the file request.
     *
     * @example Were.The.Fugawis.S01E01E02.WS.DSR.x264-NY2.mkv
     *
     * @example /series/The Office/Season 4/The Office [401] Fun Run.avi
     */
    file: string;
    /**
     * Some filenames consist of 2 or more parts. If you want to get info about second part for example you can pass 2 to this parameter
     *
     * Default: 1
     */
    part?: number;
    hash?: string;
};
type SimklSearchFileMovie = SimklMovieShort;
/** Returns episode for a Tv Show or Anime  */
type SimklSearchFileEpisode = {
    type: 'episode';
    show: SimklShowShort;
    episode: {
        title: string;
        season: number;
        episode: number;
        multipart: 0 | 1 | boolean;
        ids: Partial<SimklIdsExtended>;
    };
};
type SimklSearchFileResponse<T extends 'movie' | 'episode' | typeof SimklEntityType.Unknown = typeof SimklEntityType.Unknown> = T extends 'movie' ? SimklSearchFileMovie : T extends 'episode' ? SimklSearchFileEpisode : SimklSearchFileMovie | SimklSearchFileEpisode;

export { type SimklSearchEntity, SimklSearchEntityType, type SimklSearchEntityTypes, type SimklSearchFileEpisode, type SimklSearchFileMovie, type SimklSearchFileRequest, type SimklSearchFileResponse, type SimklSearchIdAnime, type SimklSearchIdMovie, type SimklSearchIdRequest, type SimklSearchIdResponse, type SimklSearchIdShow, type SimklSearchTextAnime, type SimklSearchTextMovie, type SimklSearchTextRequest, type SimklSearchTextResponse, type SimklSearchTextShow };
