import { SimklApiParamsExtended, SimklApiExtended, SimklApiParamsPagination } from './simkl-client.model.cjs';
import { SimklMediaType, SimklIds, SimklAirDate, SimklAnimeAndShowStatuses, SimklTrailer, SimklEntityTypes, SimklEntityType, SimklTrendingIntervals, SimklGenreYears, SimklGenreSorts, SimklPremiereParams, SimklPremiereDates, SimklAiringSorts, SimklBestFilters } from './simkl-common.model.cjs';
import { SimklEpisodeMinimal } from './simkl-episode.model.cjs';
import { SimklRatings } from './simkl-rating.model.cjs';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

type SimklShowShort = {
    title: string;
    year: number;
    type: typeof SimklMediaType.Show;
    ids: SimklIds<'slug' | 'simkl'>;
};
type SimklShowRecommendation = {
    title: string;
    year: number;
    poster: string;
    users_percent: number;
    users_count: number;
    ids: SimklIds<'slug' | 'simkl'>;
};
type SimklShowExtended = SimklShowShort & {
    year_start_end: string;
    rank: number;
    poster: string;
    fanart: string;
    first_aired: string;
    last_aired: string;
    airs: SimklAirDate;
    runtime: number;
    certification: string;
    overview: string;
    genres: string[];
    country: string;
    total_episodes: number;
    status: SimklAnimeAndShowStatuses;
    network: string;
    ratings: SimklRatings<'simkl' | 'imdb'>;
    trailer?: SimklTrailer[];
    user_recommendations?: SimklShowRecommendation[];
};
type SimklShow<T extends SimklEntityTypes = typeof SimklEntityType.Unknown> = T extends typeof SimklEntityType.Short ? SimklShowShort : T extends typeof SimklEntityType.Extended ? SimklShowExtended : SimklShowShort & Partial<SimklShowExtended>;
type SimklShowIdRequest = {
    /** Simkl ID or IMDB ID. */
    id: number | string;
} & SimklApiParamsExtended<typeof SimklApiExtended.Full>;
type SimklShowEpisodesRequest = {
    /** Simkl ID */
    id: number | string;
} & SimklApiParamsExtended<typeof SimklApiExtended.Full>;
type SimklShowTrendingRequest = {
    /** Filter within the time period. */
    interval?: SimklTrendingIntervals | string;
} & SimklApiParamsExtended<typeof SimklApiExtended.Discover>;
type SimklShowTrendingShort = {
    poster: string;
    fanart: string;
    ids: SimklIds<'simkl_id'>;
    release_date: string;
    rank: number;
    drop_rate: string;
    watched: number;
    plan_to_watch: number;
    ratings: SimklRatings<'simkl' | 'imdb'>;
    country: string;
    runtime: string;
    status: SimklAnimeAndShowStatuses;
    total_episodes: number;
    network: string;
};
type SimklShowTrendingExtended = SimklShowTrendingShort & {
    title?: string;
    url?: string;
    ids: SimklIds<'simkl_id' | 'slug' | 'tmdb'>;
    metadata?: string;
    overview?: string;
    genres?: string[];
};
type SimklShowTrending<T extends SimklEntityTypes = typeof SimklEntityType.Unknown> = T extends typeof SimklEntityType.Short ? SimklShowTrendingShort : T extends typeof SimklEntityType.Extended ? SimklShowTrendingExtended : SimklShowTrendingShort & Partial<SimklShowTrendingExtended>;
declare const SimklShowGenreSection: {
    readonly Action: "action";
    readonly Adventure: "adventure";
    readonly Animation: "animation";
    readonly AwardsShow: "awards-show";
    readonly Children: "children";
    readonly Comedy: "comedy";
    readonly Crime: "crime";
    readonly Documentary: "documentary";
    readonly Drama: "drama";
    readonly Family: "family";
    readonly Fantasy: "fantasy";
    readonly Food: "food";
    readonly GameShow: "game-show";
    readonly History: "history";
    readonly HomeAndGarden: "home-and-garden";
    readonly Horror: "horror";
    readonly Indie: "indie";
    readonly MartialArts: "martial-arts";
    readonly MiniSeries: "mini-series";
    readonly Musical: "musical";
    readonly Mystery: "mystery";
    readonly News: "news";
    readonly Podcast: "podcast";
    readonly Reality: "reality";
    readonly Romance: "romance";
    readonly ScienceFiction: "science-fiction";
    readonly Soap: "soap";
    readonly SpecialInterest: "special-interest";
    readonly Sport: "sport";
    readonly Suspense: "suspense";
    readonly TalkShow: "talk-show";
    readonly Thriller: "thriller";
    readonly Travel: "travel";
    readonly War: "war";
    readonly Western: "western";
    readonly All: "all";
};
type SimklShowGenreSections = (typeof SimklShowGenreSection)[keyof typeof SimklShowGenreSection];
declare const SimklShowGenreType: {
    readonly All: "all-types";
    readonly Entertainment: "entertainment";
    readonly Documentaries: "documentaries";
    readonly Animation: "animation-filter";
};
type SimklShowGenreTypes = (typeof SimklShowGenreType)[keyof typeof SimklShowGenreType];
declare const SimklShowGenreCountry: {
    readonly All: "all-countries";
    readonly US: "us";
    readonly UK: "uk";
    readonly CA: "ca";
    readonly KR: "kr";
    readonly JP: "jp";
};
type SimklShowGenreCountries = (typeof SimklShowGenreCountry)[keyof typeof SimklShowGenreCountry];
declare const SimklShowGenreNetwork: {
    readonly Netflix: "netflix";
    readonly Disney: "disney";
    readonly Peacock: "peacock";
    readonly AppleTV: "appletv";
    readonly Quibi: "quibi";
    readonly CBS: "cbs";
    readonly ABC: "abc";
    readonly FOX: "fox";
    readonly CW: "cw";
    readonly HBO: "hbo";
    readonly Showtime: "showtime";
    readonly USA: "usa";
    readonly Syfy: "syfy";
    readonly TNT: "tnt";
    readonly FX: "fx";
    readonly AMC: "amc";
    readonly ABCFAM: "abcfam";
    readonly Showcase: "showcase";
    readonly Starz: "starz";
    readonly MTV: "mtv";
    readonly Lifetime: "lifetime";
    readonly AE: "ae";
    readonly TVLand: "tvland";
};
type SimklShowGenreNetworks = (typeof SimklShowGenreNetwork)[keyof typeof SimklShowGenreNetwork];
type SimklShowGenreRequest = {
    /** Default: all */
    genre?: SimklShowGenreSections | string;
    /** Default: tv-shows (empty) */
    type?: SimklShowGenreTypes | string;
    /** Default: us */
    country?: SimklShowGenreCountries | string;
    /** Default: all-networks (empty) */
    network?: SimklShowGenreNetworks | string;
    /** Default: 2010s */
    year?: SimklGenreYears | string;
    /** Default: rank */
    sort?: SimklGenreSorts | string;
} & SimklApiParamsPagination;
type SimklShowGenre = {
    title: string;
    year: number;
    date: string;
    url: string;
    poster: string;
    fanart: string;
    rank: number;
    ids: SimklIds<'simkl_id' | 'slug'>;
    ratings: SimklRatings<'simkl' | 'imdb'>;
};
declare const SimklShowPremiereType: {
    readonly All: "all";
    readonly Entertainment: "entertainment";
    readonly Documentaries: "documentaries";
    readonly Animation: "animation-filter";
};
type SimklShowPremiereTypes = (typeof SimklShowPremiereType)[keyof typeof SimklShowPremiereType];
type SimklShowPremieresRequest = {
    param: SimklPremiereParams | string;
    type?: SimklShowPremiereTypes | string;
} & SimklApiParamsPagination;
type SimklShowPremiere = {
    title: string;
    year: number;
    date: string;
    url: string;
    poster: string;
    rank?: number;
    ids: SimklIds<'simkl_id' | 'slug'>;
    ratings?: SimklRatings<'simkl' | 'imdb'>;
};
type SimklShowAiringRequest = {
    date?: SimklPremiereDates | string;
    sort?: SimklAiringSorts | string;
};
type SimklShowAiring = {
    title: string;
    year: number;
    date: string;
    url: string;
    poster: string;
    rank?: number;
    ids: SimklIds<'simkl_id' | 'slug'>;
    episode: SimklEpisodeMinimal;
};
declare const SimklShowBestType: {
    readonly Series: "series";
    readonly Documentary: "documentary";
    readonly Entertainment: "entertainment";
    readonly Animation: "animation";
};
type SimklShowBestTypes = (typeof SimklShowBestType)[keyof typeof SimklShowBestType];
type SimklShowBestRequest = {
    filter: SimklBestFilters | string;
    type?: SimklShowBestTypes | string;
};
type SimklShowBest = {
    title: string;
    year: number;
    poster: string;
    url: string;
    ids: SimklIds<'simkl_id' | 'slug'>;
    ratings: SimklRatings<'simkl' | 'imdb'>;
};

export { type SimklShow, type SimklShowAiring, type SimklShowAiringRequest, type SimklShowBest, type SimklShowBestRequest, SimklShowBestType, type SimklShowBestTypes, type SimklShowEpisodesRequest, type SimklShowExtended, type SimklShowGenre, type SimklShowGenreCountries, SimklShowGenreCountry, SimklShowGenreNetwork, type SimklShowGenreNetworks, type SimklShowGenreRequest, SimklShowGenreSection, type SimklShowGenreSections, SimklShowGenreType, type SimklShowGenreTypes, type SimklShowIdRequest, type SimklShowPremiere, SimklShowPremiereType, type SimklShowPremiereTypes, type SimklShowPremieresRequest, type SimklShowRecommendation, type SimklShowShort, type SimklShowTrending, type SimklShowTrendingExtended, type SimklShowTrendingRequest, type SimklShowTrendingShort };
