import { SimklAnimeTypes } from './simkl-anime.model.cjs';
import { SimklApiParamsExtended, SimklApiExtended } from './simkl-client.model.cjs';
import { SimklIds } from './simkl-common.model.cjs';
import { SimklEpisodeShort } from './simkl-episode.model.cjs';
import { SimklMovieShort } from './simkl-movie.model.cjs';
import { SimklShowShort } from './simkl-show.model.cjs';
import './simkl-rating.model.cjs';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

declare const SimklSyncHistoryType: {
    readonly Shows: "shows";
    readonly Movies: "movies";
    readonly Anime: "anime";
};
type SimklSyncHistoryTypes = (typeof SimklSyncHistoryType)[keyof typeof SimklSyncHistoryType];
declare const SimklSyncHistoryStatus: {
    readonly Watching: "watching";
    readonly PlanToWatch: "plantowatch";
    readonly Hold: "hold";
    readonly Completed: "completed";
    readonly Dropped: "dropped";
};
type SimklSyncHistoryStatuses = (typeof SimklSyncHistoryStatus)[keyof typeof SimklSyncHistoryStatus];
type SimklSyncHistoryRequest = {
    type?: SimklSyncHistoryTypes;
    status?: SimklSyncHistoryStatuses;
    /** Returns the date when user watched the episode (watched_at). */
    episode_watched_at?: boolean | 'yes';
    /** Returns the items updated from the passed value. */
    date_from?: string;
    /** Returns more info about next to watch episodes. */
    next_watch_info?: boolean | 'yes';
} & SimklApiParamsExtended<typeof SimklApiExtended.Full>;
type NextToWatch = {
    title: string;
    episode: number;
    date: string;
};
type SimklSyncHistoryEpisode = {
    watched_at?: string;
    number: number;
};
type SimklSyncHistorySeason = {
    watched_at?: string;
    number: number;
    episodes?: SimklSyncHistoryEpisode[];
};
type SimklSyncHistoryBase = {
    status: SimklSyncHistoryStatuses;
    last_watched_at?: string;
    user_rating?: number;
    watched_episodes_count: number;
    total_episodes_count: number;
    not_aired_episodes_count: number;
};
type SimklSyncHistoryShow = SimklSyncHistoryBase & {
    last_watched?: string;
    next_to_watch?: string;
    next_to_watch_info?: NextToWatch;
    seasons?: SimklSyncHistorySeason[];
    show: {
        title: string;
        poster: string;
        year: number;
        ids: SimklIds<'simkl' | 'slug'>;
    };
};
type SimklSyncHistoryAnime = SimklSyncHistoryBase & {
    last_watched?: string;
    next_to_watch?: string;
    anime_type: SimklAnimeTypes;
    next_to_watch_info?: NextToWatch;
    seasons?: SimklSyncHistorySeason[];
    show: {
        title: string;
        poster: string;
        year: number;
        ids: SimklIds<'simkl' | 'mal'>;
    };
};
type SimklSyncHistoryMovie = SimklSyncHistoryBase & {
    movie: {
        title: string;
        poster: string;
        year: number;
        ids: SimklIds<'simkl' | 'imdb'>;
    };
};
type SimklSyncHistoryResponse = {
    shows: SimklSyncHistoryShow[];
    anime: SimklSyncHistoryAnime[];
    movies: SimklSyncHistoryMovie[];
};
type SimklSyncAddHistoryItem = {
    memo?: string;
    rating?: number;
    watched_at?: string;
    ids: SimklIds<'simkl'>;
};
type SimklSyncAddHistoryMovie = Partial<SimklMovieShort> & SimklSyncAddHistoryItem;
type SimklSyncAddHistoryShow = Partial<SimklShowShort> & {
    seasons?: SimklSyncHistorySeason[];
} & SimklSyncAddHistoryItem;
type SimklSyncAddHistoryEpisode = {
    watched_at?: string;
    ids: SimklIds<'simkl'>;
};
type SimklSyncAddHistoryRequest = {
    movies?: SimklSyncAddHistoryMovie[];
    shows?: SimklSyncAddHistoryShow[];
    episodes?: SimklSyncAddHistoryEpisode[];
};
type SimklSyncAddHistoryResponse = {
    added: {
        movies: number;
        shows: number;
        episodes: number;
    };
    not_found: {
        movies: SimklIds<'simkl'>[];
        shows: SimklIds<'simkl'>[];
        episodes: SimklIds<'simkl'>[];
    };
};
type SimklSyncRemoveHistoryRequest = {
    movies?: SimklSyncAddHistoryMovie[];
    shows?: SimklSyncAddHistoryShow[];
};
type SimklSyncRemoveHistoryResponse = {
    deleted: {
        movies: number;
        shows: number;
        episodes: number;
    };
    not_found: {
        movies: SimklIds<'simkl'>[];
        shows: SimklIds<'simkl'>[];
        episodes: SimklIds<'simkl'>[];
    };
};
type SimklSyncRatingRequest = {
    type?: SimklSyncHistoryTypes;
    rating?: 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10;
    date_from?: string;
} & SimklApiParamsExtended<typeof SimklApiExtended.Full>;
type SimklSyncRatingItem = {
    rating: 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10;
    rated_at?: string;
    ids: SimklIds<'simkl'>;
};
type SimklSyncRatingMovie = Partial<SimklMovieShort> & SimklSyncRatingItem;
type SimklSyncRatingShow = Partial<SimklShowShort> & SimklSyncRatingItem;
type SimklSyncAddRatingRequest = {
    movies?: SimklSyncRatingMovie[];
    shows?: SimklSyncRatingShow[];
};
type SimklSyncAddRatingResponse = {
    added: {
        movies: number;
        shows: number;
    };
    not_found: {
        movies: SimklIds<'simkl'>[];
        shows: SimklIds<'simkl'>[];
        episodes: SimklIds<'simkl'>[];
    };
};
type SimklSyncRemoveRatingItem<T> = {
    ids: SimklIds<'simkl'>;
} & T;
type SimklSyncRemoveRatingRequest = {
    movies?: SimklSyncRemoveRatingItem<Partial<SimklMovieShort>>[];
    shows?: SimklSyncRemoveRatingItem<Partial<SimklShowShort>>[];
};
type SimklSyncRemoveRatingResponse = {
    deleted: {
        movies: number;
        shows: number;
    };
    not_found: {
        movies: SimklIds<'simkl'>[];
        shows: SimklIds<'simkl'>[];
        episodes: SimklIds<'simkl'>[];
    };
};
type SimklSyncAddToListItem<T> = {
    ids: SimklIds<'simkl'>;
    to: SimklSyncHistoryStatuses | string;
    /** UTC datetime when the item was watched, available only for "completed" status */
    watched_at?: string;
} & T;
type SimklSyncAddToListRequest = {
    movies?: SimklSyncAddToListItem<Partial<SimklMovieShort>>[];
    shows?: SimklSyncAddToListItem<Partial<SimklShowShort>>[];
};
type SimklSyncAddToListResponse = {
    added: {
        movies: SimklSyncAddToListItem<Partial<SimklMovieShort>>[];
        shows: SimklSyncAddToListItem<Partial<SimklShowShort>>[];
    };
    not_found: {
        movies: SimklSyncAddToListItem<Partial<SimklMovieShort>>[];
        shows: SimklSyncAddToListItem<Partial<SimklShowShort>>[];
    };
};
type SimklSyncCheckRequestItem = {
    /** Movie or TV Show\Anime name */
    title?: string;
    /** Release year */
    year?: number | string;
    /** TV Show Season */
    season?: number | string;
    /** TV Show Episode number */
    episode?: number | string;
    /** Simkl ID */
    simkl?: number | string;
    /**  hulu_id. All other parameters can be empty if this one specified. */
    hulu?: number | string;
    /** Netflix movieid, this parameter is in beta and may not always work. */
    netflix?: number | string;
    /** MyAnimeList ID */
    mal?: number | string;
    /** TheTVDB ID. all other parameters can be empty if this one specified. */
    tvdb?: number | string;
    /** Required fore tmdb, if it's a TV Show */
    type?: 'show' | 'movie';
    /** The Movie Database (TMDb) ID. If you are searching for a TV Show, specify type param as well. All other parameters can be empty if this one specified. */
    tmdb?: number | string;
    /** Can be IMDB ID or full IMDB URL. All other parameters can be empty if this one specified. */
    imdb?: string;
    /** AniDB ID. All other parameters can be empty if this one specified. */
    anidb?: number | string;
};
type SimklSyncCheckRequest = {
    payload: SimklSyncCheckRequestItem[];
};
type SimklSyncCheckResponseItem = SimklSyncCheckRequestItem & {
    list?: SimklSyncHistoryStatuses;
    watched?: string;
    last_watched?: string;
    /**
     * - true: Found a match and found in user's watchlist
     * - false: Found a match but could not find in user's watchlist
     * - 'not_found': Could not find a match in Simkl database with such Title\Year or ID
     */
    result?: boolean | 'not_found';
};
type SimklSyncCheckResponse = SimklSyncCheckResponseItem[];
type SimklSyncAddToCollectionItem<T> = {
    /** UTC datetime when the item was collected. Will be used current if the parameter is skipped. */
    collected_at?: string;
    ids: SimklIds<'simkl'>;
} & T;
type SimklSyncAddToCollectionRequest = {
    movies?: SimklSyncAddToCollectionItem<Partial<SimklMovieShort>>[];
    shows?: SimklSyncAddToCollectionItem<Partial<SimklShowShort>>[];
    episodes?: SimklSyncAddToCollectionItem<Partial<SimklEpisodeShort>>[];
};
type SimklSynAddedCollectionResponse = {
    added: {
        movies: number;
        shows: number;
        episodes: number;
    };
    not_found: {
        movies: SimklIds<'simkl'>[];
        shows: SimklIds<'simkl'>[];
        episodes: SimklIds<'simkl'>[];
    };
};
type SimklSyncRemoveFromCollectionItem<T> = {
    ids: SimklIds<'simkl'>;
} & T;
type SimklSyncRemoveFromCollectionRequest = {
    movies?: SimklSyncRemoveFromCollectionItem<Partial<SimklMovieShort>>[];
    shows?: SimklSyncRemoveFromCollectionItem<Partial<SimklShowShort>>[];
};
type SimklSyncRemoveCollectionResponse = {
    deleted: {
        movies: number;
        shows: number;
        episodes: number;
    };
    not_found: {
        movies: SimklIds<'simkl'>[];
        shows: SimklIds<'simkl'>[];
        episodes: SimklIds<'simkl'>[];
    };
};

export { type NextToWatch, type SimklSynAddedCollectionResponse, type SimklSyncAddHistoryEpisode, type SimklSyncAddHistoryItem, type SimklSyncAddHistoryMovie, type SimklSyncAddHistoryRequest, type SimklSyncAddHistoryResponse, type SimklSyncAddHistoryShow, type SimklSyncAddRatingRequest, type SimklSyncAddRatingResponse, type SimklSyncAddToCollectionItem, type SimklSyncAddToCollectionRequest, type SimklSyncAddToListItem, type SimklSyncAddToListRequest, type SimklSyncAddToListResponse, type SimklSyncCheckRequest, type SimklSyncCheckRequestItem, type SimklSyncCheckResponse, type SimklSyncCheckResponseItem, type SimklSyncHistoryAnime, type SimklSyncHistoryBase, type SimklSyncHistoryEpisode, type SimklSyncHistoryMovie, type SimklSyncHistoryRequest, type SimklSyncHistoryResponse, type SimklSyncHistorySeason, type SimklSyncHistoryShow, SimklSyncHistoryStatus, type SimklSyncHistoryStatuses, SimklSyncHistoryType, type SimklSyncHistoryTypes, type SimklSyncRatingItem, type SimklSyncRatingMovie, type SimklSyncRatingRequest, type SimklSyncRatingShow, type SimklSyncRemoveCollectionResponse, type SimklSyncRemoveFromCollectionItem, type SimklSyncRemoveFromCollectionRequest, type SimklSyncRemoveHistoryRequest, type SimklSyncRemoveHistoryResponse, type SimklSyncRemoveRatingItem, type SimklSyncRemoveRatingRequest, type SimklSyncRemoveRatingResponse };
